@@ -14,7 +14,7 @@ use CPAN::Audit::Version;
 use CPAN::Audit::Query;
 use CPAN::Audit::DB;
 
-our $VERSION = '20230601.001';
+our $VERSION = '20230601.002';
 
 sub new {
 	my( $class, %params ) = @_;
@@ -63,7 +63,7 @@ sub command_module {
 		return "Module '$module' is not in database";
 	}
 
-	$dists->{$distname} = $version_range || '';
+	$dists->{$distname} = $version_range // '';
 
 	return;
 }
@@ -77,7 +77,7 @@ sub command_release {
 		return "Distribution '$distname' is not in database";
 	}
 
-	$dists->{$distname} = $version_range || '';
+	$dists->{$distname} = $version_range // '';
 
 	return;
 }
@@ -103,6 +103,24 @@ sub command_show {
 	return;
 }
 
+sub command_modules {
+	my ($self, $dists, @modules) = @_;
+	return "Usage: modules '<module>[,version-range]' '<module>[,version-range]'" unless @modules;
+
+	foreach my $module ( @modules ) {
+		my ($name, $version) = split /;/, $module;
+
+		my $failed = $self->command_module( $dists, $name, $version // '' );
+
+		if ( $failed ) {
+			$self->verbose( $failed );
+			next;
+		}
+	}
+
+	return;
+}
+
 sub command_deps {
 	my ($self, $dists, $dir) = @_;
 	$dir = '.' unless defined $dir;
@@ -157,6 +175,7 @@ sub command {
 		deps         => 'command_deps',
 		installed    => 'command_installed',
 		module       => 'command_module',
+		modules      => 'command_modules',
 		release      => 'command_release',
 		dist         => 'command_release',
 		show         => 'command_show',
